# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateNetworkClientPolicy(object):

    """Implementation of the 'updateNetworkClientPolicy' model.

    TODO: type model description here.

    Attributes:
        device_policy (string): The group policy (Whitelisted, Blocked,
            Normal, Group policy)
        group_policy_id (string): [optional] If devicePolicy param is set to
            'Group policy' this param is used to specify the group ID.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "device_policy":'devicePolicy',
        "group_policy_id":'groupPolicyId'
    }

    def __init__(self,
                 device_policy=None,
                 group_policy_id=None):
        """Constructor for the UpdateNetworkClientPolicy class"""

        # Initialize members of the class
        self.device_policy = device_policy
        self.group_policy_id = group_policy_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        device_policy = dictionary.get('devicePolicy')
        group_policy_id = dictionary.get('groupPolicyId')

        # Return an object of this model
        return cls(device_policy,
                   group_policy_id)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class AppliesToEnum(object):

    """Implementation of the 'AppliesTo' enum.

    Which kinds of admins this policy applies to. Can be one of 'All
    organization admins', 'All enterprise admins', 'All network admins', 'All
    admins of networks...', 'All admins of networks tagged...', 'Specific
    admins...', 'All admins' or 'All SAML admins'.

    Attributes:
        ENUM_ALL ORGANIZATION ADMINS: TODO: type description here.
        ENUM_ALL ENTERPRISE ADMINS: TODO: type description here.
        ENUM_ALL NETWORK ADMINS: TODO: type description here.
        ENUM_ALL ADMINS OF NETWORKS: TODO: type description here.
        ENUM_ALL ADMINS OF NETWORKS TAGGED: TODO: type description here.
        ENUM_SPECIFIC ADMINS: TODO: type description here.
        ENUM_ALL ADMINS: TODO: type description here.
        ENUM_ALL SAML ADMINS: TODO: type description here.

    """

    ENUM_ALL_ORGANIZATION_ADMINS = 'All organization admins'

    ENUM_ALL_ENTERPRISE_ADMINS = 'All enterprise admins'

    ENUM_ALL_NETWORK_ADMINS = 'All network admins'

    ENUM_ALL_ADMINS_OF_NETWORKS = 'All admins of networks...'

    ENUM_ALL_ADMINS_OF_NETWORKS_TAGGED = 'All admins of networks tagged...'

    ENUM_SPECIFIC_ADMINS = 'Specific admins...'

    ENUM_ALL_ADMINS = 'All admins'

    ENUM_ALL_SAML_ADMINS = 'All SAML admins'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Definition(object):

    """Implementation of the 'Definition' model.

    TODO: type model description here.

    Attributes:
        mtype (TypeEnum): The type of definition. Can be one of 'application',
            'applicationCategory', 'host', 'port', 'ipRange' or 'localNet'.
        value (string): If "type" is 'host', 'port', 'ipRange' or 'localNet',
            then "value" must be a string, matching either     a hostname
            (e.g. "somesite.com"), a port (e.g. 8080), or an IP range
            ("192.1.0.0",     "192.1.0.0/16", or "10.1.0.0/16:80"). 'localNet'
            also supports CIDR notation, excluding     custom ports.      If
            "type" is 'application' or 'applicationCategory', then "value"
            must be an object     with the structure { "id":
            "meraki:layer7/..." }, where "id" is the application category or  
            application ID (for a list of IDs for your network, use the
            trafficShaping/applicationCategories     endpoint).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mtype":'type',
        "value":'value'
    }

    def __init__(self,
                 mtype=None,
                 value=None):
        """Constructor for the Definition class"""

        # Initialize members of the class
        self.mtype = mtype
        self.value = value


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        mtype = dictionary.get('type')
        value = dictionary.get('value')

        # Return an object of this model
        return cls(mtype,
                   value)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CreateNetworkPiiRequest(object):

    """Implementation of the 'createNetworkPiiRequest' model.

    TODO: type model description here.

    Attributes:
        mtype (Type5Enum): One of "delete" or "restrict processing"
        datasets (list of string): The datasets related to the provided key
            that should be deleted. Only applies to "delete" requests. The
            value "all" will be expanded to all datasets applicable to this
            type. The datasets by applicable to each type are: mac (usage,
            events, traffic), email (users, loginAttempts), username (users,
            loginAttempts), bluetoothMac (client, connectivity), smDeviceId
            (device), smUserId (user)
        username (string): The username of a network log in. Only applies to
            "delete" requests.
        email (string): The email of a network user account. Only applies to
            "delete" requests.
        mac (string): The MAC of a network client device. Applies to both
            "restrict processing" and "delete" requests.
        sm_device_id (string): The sm_device_id of a Systems Manager device.
            The only way to "restrict processing" or "delete" a Systems
            Manager device. Must include "device" in the dataset for a
            "delete" request to destroy the device.
        sm_user_id (string): The sm_user_id of a Systems Manager user. The
            only way to "restrict processing" or "delete" a Systems Manager
            user. Must include "user" in the dataset for a "delete" request to
            destroy the user.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mtype":'type',
        "datasets":'datasets',
        "username":'username',
        "email":'email',
        "mac":'mac',
        "sm_device_id":'smDeviceId',
        "sm_user_id":'smUserId'
    }

    def __init__(self,
                 mtype=None,
                 datasets=None,
                 username=None,
                 email=None,
                 mac=None,
                 sm_device_id=None,
                 sm_user_id=None):
        """Constructor for the CreateNetworkPiiRequest class"""

        # Initialize members of the class
        self.mtype = mtype
        self.datasets = datasets
        self.username = username
        self.email = email
        self.mac = mac
        self.sm_device_id = sm_device_id
        self.sm_user_id = sm_user_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        mtype = dictionary.get('type')
        datasets = dictionary.get('datasets')
        username = dictionary.get('username')
        email = dictionary.get('email')
        mac = dictionary.get('mac')
        sm_device_id = dictionary.get('smDeviceId')
        sm_user_id = dictionary.get('smUserId')

        # Return an object of this model
        return cls(mtype,
                   datasets,
                   username,
                   email,
                   mac,
                   sm_device_id,
                   sm_user_id)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class Settings1Enum(object):

    """Implementation of the 'Settings1' enum.

    How firewall and traffic shaping rules are enforced. Can be 'network
    default', 'ignore' or 'custom'.

    Attributes:
        ENUM_NETWORK DEFAULT: TODO: type description here.
        IGNORE: TODO: type description here.
        CUSTOM: TODO: type description here.

    """

    ENUM_NETWORK_DEFAULT = 'network default'

    IGNORE = 'ignore'

    CUSTOM = 'custom'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Mapping(object):

    """Implementation of the 'Mapping' model.

    TODO: type model description here.

    Attributes:
        dscp (int): The Differentiated Services Code Point (DSCP) tag in the
            IP header that will be mapped to a particular Class-of-Service
            (CoS) queue. Value can be in the range of 0 to 63 inclusive.
        cos (int): The actual layer-2 CoS queue the DSCP value is mapped to.
            These are not bits set on outgoing frames. Value can be in the
            range of 0 to 5 inclusive.
        title (string): Label for the mapping (optional).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "dscp":'dscp',
        "cos":'cos',
        "title":'title'
    }

    def __init__(self,
                 dscp=None,
                 cos=None,
                 title=None):
        """Constructor for the Mapping class"""

        # Initialize members of the class
        self.dscp = dscp
        self.cos = cos
        self.title = title


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        dscp = dictionary.get('dscp')
        cos = dictionary.get('cos')
        title = dictionary.get('title')

        # Return an object of this model
        return cls(dscp,
                   cos,
                   title)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class Mode1Enum(object):

    """Implementation of the 'Mode1' enum.

    The traffic analysis mode for the network. Can be one of 'disabled' (do
    not collect traffic types),
        'basic' (collect generic traffic categories), or 'detailed' (collect
        destination hostnames).

    Attributes:
        DISABLED: TODO: type description here.
        BASIC: TODO: type description here.
        DETAILED: TODO: type description here.

    """

    DISABLED = 'disabled'

    BASIC = 'basic'

    DETAILED = 'detailed'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class Settings2Enum(object):

    """Implementation of the 'Settings2' enum.

    How URL patterns are applied. Can be 'network default', 'append' or
    'override'.

    Attributes:
        ENUM_NETWORK DEFAULT: TODO: type description here.
        APPEND: TODO: type description here.
        OVERRIDE: TODO: type description here.

    """

    ENUM_NETWORK_DEFAULT = 'network default'

    APPEND = 'append'

    OVERRIDE = 'override'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class GetHelpSubtabEnum(object):

    """Implementation of the 'GetHelpSubtab' enum.

    The 'Help -> Get Help' subtab on which Cisco Meraki KB, Product Manuals,
    and Support/Case Information are displayed. Note
        that if this subtab is hidden, branding customizations for the KB on
        'Get help', Cisco Meraki product documentation,
        and support contact info will not be visible. Can be one of 'default
        or inherit', 'hide' or 'show'.

    Attributes:
        ENUM_DEFAULT OR INHERIT: TODO: type description here.
        HIDE: TODO: type description here.
        SHOW: TODO: type description here.

    """

    ENUM_DEFAULT_OR_INHERIT = 'default or inherit'

    HIDE = 'hide'

    SHOW = 'show'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class V3AuthModeEnum(object):

    """Implementation of the 'V3AuthMode' enum.

    The SNMP version 3 authentication mode. Can be either 'MD5' or 'SHA'.

    Attributes:
        MD5: TODO: type description here.
        SHA: TODO: type description here.

    """

    MD5 = 'MD5'

    SHA = 'SHA'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateNetworkStaticRoute(object):

    """Implementation of the 'updateNetworkStaticRoute' model.

    TODO: type model description here.

    Attributes:
        name (string): The name of the static route
        subnet (string): The subnet of the static route
        gateway_ip (string): The gateway IP (next hop) of the static route
        enabled (string): The enabled state of the static route
        fixed_ip_assignments (string): The DHCP fixed IP assignments on the
            static route
        reserved_ip_ranges (string): The DHCP reserved IP ranges on the static
            route

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "subnet":'subnet',
        "gateway_ip":'gatewayIp',
        "enabled":'enabled',
        "fixed_ip_assignments":'fixedIpAssignments',
        "reserved_ip_ranges":'reservedIpRanges'
    }

    def __init__(self,
                 name=None,
                 subnet=None,
                 gateway_ip=None,
                 enabled=None,
                 fixed_ip_assignments=None,
                 reserved_ip_ranges=None):
        """Constructor for the UpdateNetworkStaticRoute class"""

        # Initialize members of the class
        self.name = name
        self.subnet = subnet
        self.gateway_ip = gateway_ip
        self.enabled = enabled
        self.fixed_ip_assignments = fixed_ip_assignments
        self.reserved_ip_ranges = reserved_ip_ranges


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        subnet = dictionary.get('subnet')
        gateway_ip = dictionary.get('gatewayIp')
        enabled = dictionary.get('enabled')
        fixed_ip_assignments = dictionary.get('fixedIpAssignments')
        reserved_ip_ranges = dictionary.get('reservedIpRanges')

        # Return an object of this model
        return cls(name,
                   subnet,
                   gateway_ip,
                   enabled,
                   fixed_ip_assignments,
                   reserved_ip_ranges)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class BlinkNetworkDeviceLeds(object):

    """Implementation of the 'blinkNetworkDeviceLeds' model.

    TODO: type model description here.

    Attributes:
        duration (int): The duration in seconds. Must be between 5 and 120.
            Default is 20 seconds
        period (int): The period in milliseconds. Must be between 100 and
            1000. Default is 160 milliseconds
        duty (int): The duty cycle as the percent active. Must be between 10
            and 90. Default is 50.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "duration":'duration',
        "period":'period',
        "duty":'duty'
    }

    def __init__(self,
                 duration=None,
                 period=None,
                 duty=None):
        """Constructor for the BlinkNetworkDeviceLeds class"""

        # Initialize members of the class
        self.duration = duration
        self.period = period
        self.duty = duty


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        duration = dictionary.get('duration')
        period = dictionary.get('period')
        duty = dictionary.get('duty')

        # Return an object of this model
        return cls(duration,
                   period,
                   duty)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class ApBandSettings(object):

    """Implementation of the 'ApBandSettings' model.

    Settings that will be enabled if selectionType is set to 'ap'.

    Attributes:
        band_operation_mode (BandOperationModeEnum): Choice between 'dual',
            '2.4ghz' or '5ghz'. Defaults to dual.
        band_steering_enabled (bool): Steers client to most open band. Can be
            either true or false. Defaults to true.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "band_operation_mode":'bandOperationMode',
        "band_steering_enabled":'bandSteeringEnabled'
    }

    def __init__(self,
                 band_operation_mode=None,
                 band_steering_enabled=None):
        """Constructor for the ApBandSettings class"""

        # Initialize members of the class
        self.band_operation_mode = band_operation_mode
        self.band_steering_enabled = band_steering_enabled


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        band_operation_mode = dictionary.get('bandOperationMode')
        band_steering_enabled = dictionary.get('bandSteeringEnabled')

        # Return an object of this model
        return cls(band_operation_mode,
                   band_steering_enabled)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class AllowedUrlPatterns(object):

    """Implementation of the 'AllowedUrlPatterns' model.

    Settings for whitelisted URL patterns

    Attributes:
        settings (Settings2Enum): How URL patterns are applied. Can be
            'network default', 'append' or 'override'.
        patterns (list of string): A whitelist of URL patterns to allow

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "settings":'settings',
        "patterns":'patterns'
    }

    def __init__(self,
                 settings=None,
                 patterns=None):
        """Constructor for the AllowedUrlPatterns class"""

        # Initialize members of the class
        self.settings = settings
        self.patterns = patterns


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        settings = dictionary.get('settings')
        patterns = dictionary.get('patterns')

        # Return an object of this model
        return cls(settings,
                   patterns)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class VendorConfig(object):

    """Implementation of the 'VendorConfig' model.

    TODO: type model description here.

    Attributes:
        key (string): The key for an object in VendorConfig
        mtype (string): The type for an object in VendorConfig. Can be one of
            'manual_string', 'manual_int', 'manual_boolean', 'manual_choice',
            'manual_multiselect', 'manual_list', 'auto_username',
            'auto_email', 'auto_mac_address', 'auto_serial_number',
            'auto_notes' or 'auto_name'
        value (string): The value for an object in VendorConfig

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "key":'key',
        "mtype":'type',
        "value":'value'
    }

    def __init__(self,
                 key=None,
                 mtype=None,
                 value=None):
        """Constructor for the VendorConfig class"""

        # Initialize members of the class
        self.key = key
        self.mtype = mtype
        self.value = value


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        key = dictionary.get('key')
        mtype = dictionary.get('type')
        value = dictionary.get('value')

        # Return an object of this model
        return cls(key,
                   mtype,
                   value)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CreateNetworkSwitchSettingsQosRule(object):

    """Implementation of the 'createNetworkSwitchSettingsQosRule' model.

    TODO: type model description here.

    Attributes:
        vlan (int): The VLAN of the incoming packet. A null value will match
            any VLAN.
        protocol (Protocol4Enum): The protocol of the incoming packet. Can be
            one of "ANY", "TCP" or "UDP". Default value is "ANY"
        src_port (int): The source port of the incoming packet. Applicable
            only if protocol is TCP or UDP.
        src_port_range (string): The source port range of the incoming packet.
            Applicable only if protocol is set to TCP or UDP. Example: 70-80
        dst_port (int): The destination port of the incoming packet.
            Applicable only if protocol is TCP or UDP.
        dst_port_range (string): The destination port range of the incoming
            packet. Applicable only if protocol is set to TCP or UDP. Example:
            70-80
        dscp (int): DSCP tag. Set this to -1 to trust incoming DSCP. Default
            value is 0

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "vlan":'vlan',
        "protocol":'protocol',
        "src_port":'srcPort',
        "src_port_range":'srcPortRange',
        "dst_port":'dstPort',
        "dst_port_range":'dstPortRange',
        "dscp":'dscp'
    }

    def __init__(self,
                 vlan=None,
                 protocol=None,
                 src_port=None,
                 src_port_range=None,
                 dst_port=None,
                 dst_port_range=None,
                 dscp=None):
        """Constructor for the CreateNetworkSwitchSettingsQosRule class"""

        # Initialize members of the class
        self.vlan = vlan
        self.protocol = protocol
        self.src_port = src_port
        self.src_port_range = src_port_range
        self.dst_port = dst_port
        self.dst_port_range = dst_port_range
        self.dscp = dscp


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        vlan = dictionary.get('vlan')
        protocol = dictionary.get('protocol')
        src_port = dictionary.get('srcPort')
        src_port_range = dictionary.get('srcPortRange')
        dst_port = dictionary.get('dstPort')
        dst_port_range = dictionary.get('dstPortRange')
        dscp = dictionary.get('dscp')

        # Return an object of this model
        return cls(vlan,
                   protocol,
                   src_port,
                   src_port_range,
                   dst_port,
                   dst_port_range,
                   dscp)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.power_exception

class UpdateNetworkSwitchSettings(object):

    """Implementation of the 'updateNetworkSwitchSettings' model.

    TODO: type model description here.

    Attributes:
        vlan (int): Management VLAN
        use_combined_power (bool): The use Combined Power as the default
            behavior of secondary power supplies on supported devices.
        power_exceptions (list of PowerException): Exceptions on a per switch
            basis to "useCombinedPower"

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "vlan":'vlan',
        "use_combined_power":'useCombinedPower',
        "power_exceptions":'powerExceptions'
    }

    def __init__(self,
                 vlan=None,
                 use_combined_power=None,
                 power_exceptions=None):
        """Constructor for the UpdateNetworkSwitchSettings class"""

        # Initialize members of the class
        self.vlan = vlan
        self.use_combined_power = use_combined_power
        self.power_exceptions = power_exceptions


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        vlan = dictionary.get('vlan')
        use_combined_power = dictionary.get('useCombinedPower')
        power_exceptions = None
        if dictionary.get('powerExceptions') != None:
            power_exceptions = list()
            for structure in dictionary.get('powerExceptions'):
                power_exceptions.append(test_meraki.models.power_exception.PowerException.from_dictionary(structure))

        # Return an object of this model
        return cls(vlan,
                   use_combined_power,
                   power_exceptions)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CheckinNetworkSmDevices(object):

    """Implementation of the 'checkinNetworkSmDevices' model.

    TODO: type model description here.

    Attributes:
        wifi_macs (string): The wifiMacs of the devices to be checked-in.
        ids (string): The ids of the devices to be checked-in.
        serials (string): The serials of the devices to be checked-in.
        scope (string): The scope (one of all, none, withAny, withAll,
            withoutAny, or withoutAll) and a set of tags of the devices to be
            checked-in.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "wifi_macs":'wifiMacs',
        "ids":'ids',
        "serials":'serials',
        "scope":'scope'
    }

    def __init__(self,
                 wifi_macs=None,
                 ids=None,
                 serials=None,
                 scope=None):
        """Constructor for the CheckinNetworkSmDevices class"""

        # Initialize members of the class
        self.wifi_macs = wifi_macs
        self.ids = ids
        self.serials = serials
        self.scope = scope


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        wifi_macs = dictionary.get('wifiMacs')
        ids = dictionary.get('ids')
        serials = dictionary.get('serials')
        scope = dictionary.get('scope')

        # Return an object of this model
        return cls(wifi_macs,
                   ids,
                   serials,
                   scope)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateNetworkDeviceWirelessRadioSettings(object):

    """Implementation of the 'updateNetworkDeviceWirelessRadioSettings' model.

    TODO: type model description here.

    Attributes:
        rf_profile_id (int): The ID of an RF profile to assign to the device.
            If the value of this parameter is null, the appropriate basic RF
            profile     (indoor or outdoor) will be assigned to the device.
            Assigning an RF profile will clear ALL manually configured
            overrides     on the device (channel width, channel, power).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "rf_profile_id":'rfProfileId'
    }

    def __init__(self,
                 rf_profile_id=None):
        """Constructor for the UpdateNetworkDeviceWirelessRadioSettings class"""

        # Initialize members of the class
        self.rf_profile_id = rf_profile_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        rf_profile_id = dictionary.get('rfProfileId')

        # Return an object of this model
        return cls(rf_profile_id)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.monday
import test_meraki.models.tuesday
import test_meraki.models.wednesday
import test_meraki.models.thursday
import test_meraki.models.friday
import test_meraki.models.saturday
import test_meraki.models.sunday

class Scheduling(object):

    """Implementation of the 'Scheduling' model.

    The schedule for the group policy. Schedules are applied to days of the
    week.

    Attributes:
        enabled (bool): Whether scheduling is enabled (true) or disabled
            (false). Defaults to false. If true, the schedule objects for each
            day of the week (monday - sunday) are parsed.
        monday (Monday): The schedule object for Monday.
        tuesday (Tuesday): The schedule object for Tuesday.
        wednesday (Wednesday): The schedule object for Wednesday.
        thursday (Thursday): The schedule object for Thursday.
        friday (Friday): The schedule object for Friday.
        saturday (Saturday): The schedule object for Saturday.
        sunday (Sunday): The schedule object for Sunday.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "enabled":'enabled',
        "monday":'monday',
        "tuesday":'tuesday',
        "wednesday":'wednesday',
        "thursday":'thursday',
        "friday":'friday',
        "saturday":'saturday',
        "sunday":'sunday'
    }

    def __init__(self,
                 enabled=None,
                 monday=None,
                 tuesday=None,
                 wednesday=None,
                 thursday=None,
                 friday=None,
                 saturday=None,
                 sunday=None):
        """Constructor for the Scheduling class"""

        # Initialize members of the class
        self.enabled = enabled
        self.monday = monday
        self.tuesday = tuesday
        self.wednesday = wednesday
        self.thursday = thursday
        self.friday = friday
        self.saturday = saturday
        self.sunday = sunday


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        enabled = dictionary.get('enabled')
        monday = test_meraki.models.monday.Monday.from_dictionary(dictionary.get('monday')) if dictionary.get('monday') else None
        tuesday = test_meraki.models.tuesday.Tuesday.from_dictionary(dictionary.get('tuesday')) if dictionary.get('tuesday') else None
        wednesday = test_meraki.models.wednesday.Wednesday.from_dictionary(dictionary.get('wednesday')) if dictionary.get('wednesday') else None
        thursday = test_meraki.models.thursday.Thursday.from_dictionary(dictionary.get('thursday')) if dictionary.get('thursday') else None
        friday = test_meraki.models.friday.Friday.from_dictionary(dictionary.get('friday')) if dictionary.get('friday') else None
        saturday = test_meraki.models.saturday.Saturday.from_dictionary(dictionary.get('saturday')) if dictionary.get('saturday') else None
        sunday = test_meraki.models.sunday.Sunday.from_dictionary(dictionary.get('sunday')) if dictionary.get('sunday') else None

        # Return an object of this model
        return cls(enabled,
                   monday,
                   tuesday,
                   wednesday,
                   thursday,
                   friday,
                   saturday,
                   sunday)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class ProtectedNetworks(object):

    """Implementation of the 'ProtectedNetworks' model.

    Set the included/excluded networks from the intrusion engine (optional -
    omitting will leave current config unchanged). This is available only in
    'passthrough' mode

    Attributes:
        use_default (bool): true/false whether to use special IPv4 addresses:
            https://tools.ietf.org/html/rfc5735 (required). Default value is
            true if none currently saved
        included_cidr (list of string): list of IP addresses or subnets being
            protected (required if 'useDefault' is false)
        excluded_cidr (list of string): list of IP addresses or subnets being
            excluded from protection (required if 'useDefault' is false)

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "use_default":'useDefault',
        "included_cidr":'includedCidr',
        "excluded_cidr":'excludedCidr'
    }

    def __init__(self,
                 use_default=None,
                 included_cidr=None,
                 excluded_cidr=None):
        """Constructor for the ProtectedNetworks class"""

        # Initialize members of the class
        self.use_default = use_default
        self.included_cidr = included_cidr
        self.excluded_cidr = excluded_cidr


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        use_default = dictionary.get('useDefault')
        included_cidr = dictionary.get('includedCidr')
        excluded_cidr = dictionary.get('excludedCidr')

        # Return an object of this model
        return cls(use_default,
                   included_cidr,
                   excluded_cidr)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class Type1Enum(object):

    """Implementation of the 'Type1' enum.

    Type of the L7 Rule. Must be 'application', 'applicationCategory', 'host',
    'port' or 'ipRange'

    Attributes:
        APPLICATION: TODO: type description here.
        APPLICATIONCATEGORY: TODO: type description here.
        HOST: TODO: type description here.
        PORT: TODO: type description here.
        IPRANGE: TODO: type description here.

    """

    APPLICATION = 'application'

    APPLICATIONCATEGORY = 'applicationCategory'

    HOST = 'host'

    PORT = 'port'

    IPRANGE = 'ipRange'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateNetworkSwitchSettingsDhcpServerPolicy(object):

    """Implementation of the 'updateNetworkSwitchSettingsDhcpServerPolicy' model.

    TODO: type model description here.

    Attributes:
        default_policy (DefaultPolicyEnum): 'allow' or 'block' new DHCP
            servers. Default value is 'allow'.
        allowed_servers (list of string): List the MAC addresses of DHCP
            servers to permit on the network. Applicable only if defaultPolicy
            is set to block. An empty array will clear the entries.
        blocked_servers (list of string): List the MAC addresses of DHCP
            servers to block on the network. Applicable only if defaultPolicy
            is set to allow. An empty array will clear the entries.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "default_policy":'defaultPolicy',
        "allowed_servers":'allowedServers',
        "blocked_servers":'blockedServers'
    }

    def __init__(self,
                 default_policy=None,
                 allowed_servers=None,
                 blocked_servers=None):
        """Constructor for the UpdateNetworkSwitchSettingsDhcpServerPolicy class"""

        # Initialize members of the class
        self.default_policy = default_policy
        self.allowed_servers = allowed_servers
        self.blocked_servers = blocked_servers


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        default_policy = dictionary.get('defaultPolicy')
        allowed_servers = dictionary.get('allowedServers')
        blocked_servers = dictionary.get('blockedServers')

        # Return an object of this model
        return cls(default_policy,
                   allowed_servers,
                   blocked_servers)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.destination

class UpdateNetworkConnectivityMonitoringDestinations(object):

    """Implementation of the 'updateNetworkConnectivityMonitoringDestinations' model.

    TODO: type model description here.

    Attributes:
        destinations (list of Destination): The list of connectivity
            monitoring destinations

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "destinations":'destinations'
    }

    def __init__(self,
                 destinations=None):
        """Constructor for the UpdateNetworkConnectivityMonitoringDestinations class"""

        # Initialize members of the class
        self.destinations = destinations


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        destinations = None
        if dictionary.get('destinations') != None:
            destinations = list()
            for structure in dictionary.get('destinations'):
                destinations.append(test_meraki.models.destination.Destination.from_dictionary(structure))

        # Return an object of this model
        return cls(destinations)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Subnet(object):

    """Implementation of the 'Subnet' model.

    TODO: type model description here.

    Attributes:
        local_subnet (string): The CIDR notation subnet used within the VPN
        use_vpn (bool): Indicates the presence of the subnet in the VPN

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "local_subnet":'localSubnet',
        "use_vpn":'useVpn'
    }

    def __init__(self,
                 local_subnet=None,
                 use_vpn=None):
        """Constructor for the Subnet class"""

        # Initialize members of the class
        self.local_subnet = local_subnet
        self.use_vpn = use_vpn


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        local_subnet = dictionary.get('localSubnet')
        use_vpn = dictionary.get('useVpn')

        # Return an object of this model
        return cls(local_subnet,
                   use_vpn)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CreateNetworkVlan(object):

    """Implementation of the 'createNetworkVlan' model.

    TODO: type model description here.

    Attributes:
        id (string): The VLAN ID of the new VLAN (must be between 1 and 4094)
        name (string): The name of the new VLAN
        subnet (string): The subnet of the VLAN
        appliance_ip (string): The local IP of the appliance on the VLAN

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id":'id',
        "name":'name',
        "subnet":'subnet',
        "appliance_ip":'applianceIp'
    }

    def __init__(self,
                 id=None,
                 name=None,
                 subnet=None,
                 appliance_ip=None):
        """Constructor for the CreateNetworkVlan class"""

        # Initialize members of the class
        self.id = id
        self.name = name
        self.subnet = subnet
        self.appliance_ip = appliance_ip


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        name = dictionary.get('name')
        subnet = dictionary.get('subnet')
        appliance_ip = dictionary.get('applianceIp')

        # Return an object of this model
        return cls(id,
                   name,
                   subnet,
                   appliance_ip)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class Protocol3Enum(object):

    """Implementation of the 'Protocol3' enum.

    The type of protocol (must be 'tcp', 'udp', or 'any').

    Attributes:
        TCP: TODO: type description here.
        UDP: TODO: type description here.
        ANY: TODO: type description here.

    """

    TCP = 'tcp'

    UDP = 'udp'

    ANY = 'any'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.port_schedule

class UpdateNetworkSwitchPortSchedule(object):

    """Implementation of the 'updateNetworkSwitchPortSchedule' model.

    TODO: type model description here.

    Attributes:
        name (string): The name for your port schedule.
        port_schedule (PortSchedule): The schedule for switch port scheduling.
            Schedules are applied to days of the week.     When it's empty,
            default schedule with all days of a week are configured.     Any
            unspecified day in the schedule is added as a default schedule
            configuration of the day.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "port_schedule":'portSchedule'
    }

    def __init__(self,
                 name=None,
                 port_schedule=None):
        """Constructor for the UpdateNetworkSwitchPortSchedule class"""

        # Initialize members of the class
        self.name = name
        self.port_schedule = port_schedule


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        port_schedule = test_meraki.models.port_schedule.PortSchedule.from_dictionary(dictionary.get('portSchedule')) if dictionary.get('portSchedule') else None

        # Return an object of this model
        return cls(name,
                   port_schedule)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CreateNetworkStaticRoute(object):

    """Implementation of the 'createNetworkStaticRoute' model.

    TODO: type model description here.

    Attributes:
        name (string): The name of the new static route
        subnet (string): The subnet of the static route
        gateway_ip (string): The gateway IP (next hop) of the static route

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "subnet":'subnet',
        "gateway_ip":'gatewayIp'
    }

    def __init__(self,
                 name=None,
                 subnet=None,
                 gateway_ip=None):
        """Constructor for the CreateNetworkStaticRoute class"""

        # Initialize members of the class
        self.name = name
        self.subnet = subnet
        self.gateway_ip = gateway_ip


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        subnet = dictionary.get('subnet')
        gateway_ip = dictionary.get('gatewayIp')

        # Return an object of this model
        return cls(name,
                   subnet,
                   gateway_ip)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class Protocol5Enum(object):

    """Implementation of the 'Protocol5' enum.

    The protocol of the incoming packet. Can be one of "ANY", "TCP" or "UDP".
    Default value is "ANY".

    Attributes:
        ANY: TODO: type description here.
        TCP: TODO: type description here.
        UDP: TODO: type description here.

    """

    ANY = 'ANY'

    TCP = 'TCP'

    UDP = 'UDP'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.protected_networks

class UpdateNetworkSecurityIntrusionSettings(object):

    """Implementation of the 'updateNetworkSecurityIntrusionSettings' model.

    TODO: type model description here.

    Attributes:
        mode (string): Set mode to 'disabled'/'detection'/'prevention'
            (optional - omitting will leave current config unchanged)
        ids_rulesets (string): Set the detection ruleset
            'connectivity'/'balanced'/'security' (optional - omitting will
            leave current config unchanged). Default value is 'balanced' if
            none currently saved
        protected_networks (ProtectedNetworks): Set the included/excluded
            networks from the intrusion engine (optional - omitting will leave
            current config unchanged). This is available only in 'passthrough'
            mode

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mode":'mode',
        "ids_rulesets":'idsRulesets',
        "protected_networks":'protectedNetworks'
    }

    def __init__(self,
                 mode=None,
                 ids_rulesets=None,
                 protected_networks=None):
        """Constructor for the UpdateNetworkSecurityIntrusionSettings class"""

        # Initialize members of the class
        self.mode = mode
        self.ids_rulesets = ids_rulesets
        self.protected_networks = protected_networks


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        mode = dictionary.get('mode')
        ids_rulesets = dictionary.get('idsRulesets')
        protected_networks = test_meraki.models.protected_networks.ProtectedNetworks.from_dictionary(dictionary.get('protectedNetworks')) if dictionary.get('protectedNetworks') else None

        # Return an object of this model
        return cls(mode,
                   ids_rulesets,
                   protected_networks)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class L3FirewallRule(object):

    """Implementation of the 'L3FirewallRule' model.

    TODO: type model description here.

    Attributes:
        comment (string): Description of the rule (optional)
        policy (string): 'allow' or 'deny' traffic specified by this rule
        protocol (string): The type of protocol (must be 'tcp', 'udp', 'icmp'
            or 'any')
        dest_port (string): Destination port (integer in the range 1-65535), a
            port range (e.g. 8080-9090), or 'any'
        dest_cidr (string): Destination IP address (in IP or CIDR notation), a
            fully-qualified domain name (FQDN, if your network supports it) or
            'any'.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "policy":'policy',
        "protocol":'protocol',
        "dest_cidr":'destCidr',
        "comment":'comment',
        "dest_port":'destPort'
    }

    def __init__(self,
                 policy=None,
                 protocol=None,
                 dest_cidr=None,
                 comment=None,
                 dest_port=None):
        """Constructor for the L3FirewallRule class"""

        # Initialize members of the class
        self.comment = comment
        self.policy = policy
        self.protocol = protocol
        self.dest_port = dest_port
        self.dest_cidr = dest_cidr


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        policy = dictionary.get('policy')
        protocol = dictionary.get('protocol')
        dest_cidr = dictionary.get('destCidr')
        comment = dictionary.get('comment')
        dest_port = dictionary.get('destPort')

        # Return an object of this model
        return cls(policy,
                   protocol,
                   dest_cidr,
                   comment,
                   dest_port)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CustomPieChartItem(object):

    """Implementation of the 'CustomPieChartItem' model.

    TODO: type model description here.

    Attributes:
        name (string): The name of the custom pie chart item.
        mtype (Type7Enum): The signature type for the custom pie chart item.
            Can be one of 'host', 'port' or 'ipRange'.
        value (string): The value of the custom pie chart item. Valid syntax
            depends on the signature type of the chart item     (see sample
            request/response for more details).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "mtype":'type',
        "value":'value'
    }

    def __init__(self,
                 name=None,
                 mtype=None,
                 value=None):
        """Constructor for the CustomPieChartItem class"""

        # Initialize members of the class
        self.name = name
        self.mtype = mtype
        self.value = value


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        mtype = dictionary.get('type')
        value = dictionary.get('value')

        # Return an object of this model
        return cls(name,
                   mtype,
                   value)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.default_destinations
import test_meraki.models.alert

class UpdateNetworkAlertSettings(object):

    """Implementation of the 'updateNetworkAlertSettings' model.

    TODO: type model description here.

    Attributes:
        default_destinations (DefaultDestinations): The network_wide
            destinations for all alerts on the network.
        alerts (list of Alert): Alert-specific configuration for each type.
            Only alerts that pertain to the network can be updated.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "default_destinations":'defaultDestinations',
        "alerts":'alerts'
    }

    def __init__(self,
                 default_destinations=None,
                 alerts=None):
        """Constructor for the UpdateNetworkAlertSettings class"""

        # Initialize members of the class
        self.default_destinations = default_destinations
        self.alerts = alerts


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        default_destinations = test_meraki.models.default_destinations.DefaultDestinations.from_dictionary(dictionary.get('defaultDestinations')) if dictionary.get('defaultDestinations') else None
        alerts = None
        if dictionary.get('alerts') != None:
            alerts = list()
            for structure in dictionary.get('alerts'):
                alerts.append(test_meraki.models.alert.Alert.from_dictionary(structure))

        # Return an object of this model
        return cls(default_destinations,
                   alerts)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from test_meraki.api_helper import APIHelper
from test_meraki.configuration import Configuration
from test_meraki.controllers.base_controller import BaseController
from test_meraki.http.auth.custom_header_auth import CustomHeaderAuth

class RadioSettingsController(BaseController):

    """A Controller to access Endpoints in the test_meraki API."""


    def get_network_device_wireless_radio_settings(self,
                                                   network_id,
                                                   serial):
        """Does a GET request to /networks/{networkId}/devices/{serial}/wireless/radioSettings.

        Return the radio settings of a device

        Args:
            network_id (string): TODO: type description here. Example: 
            serial (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/devices/{serial}/wireless/radioSettings'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'serial': serial
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_device_wireless_radio_settings(self,
                                                      network_id,
                                                      serial,
                                                      update_network_device_wireless_radio_settings=None):
        """Does a PUT request to /networks/{networkId}/devices/{serial}/wireless/radioSettings.

        Update the radio settings of a device

        Args:
            network_id (string): TODO: type description here. Example: 
            serial (string): TODO: type description here. Example: 
            update_network_device_wireless_radio_settings
                (UpdateNetworkDeviceWirelessRadioSettings, optional): TODO:
                type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/devices/{serial}/wireless/radioSettings'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'serial': serial
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_device_wireless_radio_settings))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_wireless_rf_profiles(self,
                                         network_id,
                                         include_template_profiles=None):
        """Does a GET request to /networks/{networkId}/wireless/rfProfiles.

        List the non-basic RF profiles for this network

        Args:
            network_id (string): TODO: type description here. Example: 
            include_template_profiles (bool, optional): If the network is
                bound to a template, this parameter controls whether or not
                the non-basic RF profiles defined on the template     should
                be included in the response alongside the non-basic profiles
                defined on the bound network. Defaults to false.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/wireless/rfProfiles'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'includeTemplateProfiles': include_template_profiles
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_network_wireless_rf_profile(self,
                                           network_id,
                                           create_network_wireless_rf_profile):
        """Does a POST request to /networks/{networkId}/wireless/rfProfiles.

        Creates new RF profile for this network

        Args:
            network_id (string): TODO: type description here. Example: 
            create_network_wireless_rf_profile
                (CreateNetworkWirelessRfProfile): TODO: type description here.
                Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/wireless/rfProfiles'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(create_network_wireless_rf_profile))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_wireless_rf_profile(self,
                                           network_id,
                                           rf_profile_id,
                                           update_network_wireless_rf_profile=None):
        """Does a PUT request to /networks/{networkId}/wireless/rfProfiles/{rfProfileId}.

        Updates specified RF profile for this network

        Args:
            network_id (string): TODO: type description here. Example: 
            rf_profile_id (string): TODO: type description here. Example: 
            update_network_wireless_rf_profile
                (UpdateNetworkWirelessRfProfile, optional): TODO: type
                description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/wireless/rfProfiles/{rfProfileId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'rfProfileId': rf_profile_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_wireless_rf_profile))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def delete_network_wireless_rf_profile(self,
                                           network_id,
                                           rf_profile_id):
        """Does a DELETE request to /networks/{networkId}/wireless/rfProfiles/{rfProfileId}.

        Delete a RF Profile

        Args:
            network_id (string): TODO: type description here. Example: 
            rf_profile_id (string): TODO: type description here. Example: 

        Returns:
            void: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/wireless/rfProfiles/{rfProfileId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'rfProfileId': rf_profile_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.delete(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

    def get_network_wireless_rf_profile(self,
                                        network_id,
                                        rf_profile_id):
        """Does a GET request to /networks/{networkId}/wireless/rfProfiles/{rfProfileId}.

        Return a RF profile

        Args:
            network_id (string): TODO: type description here. Example: 
            rf_profile_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/wireless/rfProfiles/{rfProfileId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'rfProfileId': rf_profile_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body



# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class ApTagsAndVlanId(object):

    """Implementation of the 'ApTagsAndVlanId' model.

    TODO: type model description here.

    Attributes:
        tags (string): Comma-separated list of AP tags
        vlan_id (int): Numerical identifier that is assigned to the VLAN

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "tags":'tags',
        "vlan_id":'vlanId'
    }

    def __init__(self,
                 tags=None,
                 vlan_id=None):
        """Constructor for the ApTagsAndVlanId class"""

        # Initialize members of the class
        self.tags = tags
        self.vlan_id = vlan_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        tags = dictionary.get('tags')
        vlan_id = dictionary.get('vlanId')

        # Return an object of this model
        return cls(tags,
                   vlan_id)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Rule5(object):

    """Implementation of the 'Rule5' model.

    TODO: type model description here.

    Attributes:
        public_ip (string): The IP address that will be used to access the
            internal resource from the WAN
        uplink (string): The physical WAN interface on which the traffic will
            arrive ('internet1' or, if available, 'internet2')
        port_rules (list of object): An array of associated forwarding rules
        name (string): A description of the rule
        protocol (string): 'tcp' or 'udp'
        public_port (string): Destination port of the traffic that is arriving
            on the WAN
        local_ip (string): Local IP address to which traffic will be
            forwarded
        local_port (string): Destination port of the forwarded traffic that
            will be sent from the MX to the specified host on the LAN. If you
            simply wish to forward the traffic without translating the port,
            this should be the same as the Public port
        allowed_ips (string): Remote IP addresses or ranges that are permitted
            to access the internal resource via this port forwarding rule, or
            'any'

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "public_ip":'publicIp',
        "uplink":'uplink',
        "port_rules":'portRules',
        "name":'name',
        "protocol":'protocol',
        "public_port":'publicPort',
        "local_ip":'localIp',
        "local_port":'localPort',
        "allowed_ips":'allowedIps'
    }

    def __init__(self,
                 public_ip=None,
                 uplink=None,
                 port_rules=None,
                 name=None,
                 protocol=None,
                 public_port=None,
                 local_ip=None,
                 local_port=None,
                 allowed_ips=None):
        """Constructor for the Rule5 class"""

        # Initialize members of the class
        self.public_ip = public_ip
        self.uplink = uplink
        self.port_rules = port_rules
        self.name = name
        self.protocol = protocol
        self.public_port = public_port
        self.local_ip = local_ip
        self.local_port = local_port
        self.allowed_ips = allowed_ips


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        public_ip = dictionary.get('publicIp')
        uplink = dictionary.get('uplink')
        port_rules = dictionary.get('portRules')
        name = dictionary.get('name')
        protocol = dictionary.get('protocol')
        public_port = dictionary.get('publicPort')
        local_ip = dictionary.get('localIp')
        local_port = dictionary.get('localPort')
        allowed_ips = dictionary.get('allowedIps')

        # Return an object of this model
        return cls(public_ip,
                   uplink,
                   port_rules,
                   name,
                   protocol,
                   public_port,
                   local_ip,
                   local_port,
                   allowed_ips)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.definition
import test_meraki.models.per_client_bandwidth_limits

class Rule9(object):

    """Implementation of the 'Rule9' model.

    TODO: type model description here.

    Attributes:
        definitions (list of Definition): A list of objects describing the
            definitions of your traffic shaping rule. At least one definition
            is required.
        per_client_bandwidth_limits (PerClientBandwidthLimits): An object
            describing the bandwidth settings for your rule.
        dscp_tag_value (int): The DSCP tag applied by your rule. null means
            'Do not change DSCP tag'.     For a list of possible tag values,
            use the trafficShaping/dscpTaggingOptions endpoint.
        pcp_tag_value (int): The PCP tag applied by your rule. Can be 0
            (lowest priority) through 7 (highest priority).     null means 'Do
            not set PCP tag'.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "definitions":'definitions',
        "per_client_bandwidth_limits":'perClientBandwidthLimits',
        "dscp_tag_value":'dscpTagValue',
        "pcp_tag_value":'pcpTagValue'
    }

    def __init__(self,
                 definitions=None,
                 per_client_bandwidth_limits=None,
                 dscp_tag_value=None,
                 pcp_tag_value=None):
        """Constructor for the Rule9 class"""

        # Initialize members of the class
        self.definitions = definitions
        self.per_client_bandwidth_limits = per_client_bandwidth_limits
        self.dscp_tag_value = dscp_tag_value
        self.pcp_tag_value = pcp_tag_value


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        definitions = None
        if dictionary.get('definitions') != None:
            definitions = list()
            for structure in dictionary.get('definitions'):
                definitions.append(test_meraki.models.definition.Definition.from_dictionary(structure))
        per_client_bandwidth_limits = test_meraki.models.per_client_bandwidth_limits.PerClientBandwidthLimits.from_dictionary(dictionary.get('perClientBandwidthLimits')) if dictionary.get('perClientBandwidthLimits') else None
        dscp_tag_value = dictionary.get('dscpTagValue')
        pcp_tag_value = dictionary.get('pcpTagValue')

        # Return an object of this model
        return cls(definitions,
                   per_client_bandwidth_limits,
                   dscp_tag_value,
                   pcp_tag_value)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from test_meraki.api_helper import APIHelper
from test_meraki.configuration import Configuration
from test_meraki.controllers.base_controller import BaseController
from test_meraki.http.auth.custom_header_auth import CustomHeaderAuth

class LicensesController(BaseController):

    """A Controller to access Endpoints in the test_meraki API."""


    def get_organization_licenses(self,
                                  organization_id,
                                  per_page=None,
                                  starting_after=None,
                                  ending_before=None,
                                  device_serial=None,
                                  network_id=None,
                                  state=None):
        """Does a GET request to /organizations/{organizationId}/licenses.

        List the licenses for an organization

        Args:
            organization_id (string): TODO: type description here. Example: 
            per_page (int, optional): The number of entries per page returned.
                Acceptable range is 3 - 1000. Default is 1000.
            starting_after (string, optional): A token used by the server to
                indicate the start of the page. Often this is a timestamp or
                an ID but it is not limited to those. This parameter should
                not be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.
            ending_before (string, optional): A token used by the server to
                indicate the end of the page. Often this is a timestamp or an
                ID but it is not limited to those. This parameter should not
                be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.
            device_serial (string, optional): Filter the licenses to those
                assigned to a particular device
            network_id (string, optional): Filter the licenses to those
                assigned in a particular network
            state (StateEnum, optional): Filter the licenses to those in a
                particular state. Can be one of 'active', 'expired',
                'expiring', 'unused', 'unusedActive' or 'recentlyQueued'

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/licenses'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'perPage': per_page,
            'startingAfter': starting_after,
            'endingBefore': ending_before,
            'deviceSerial': device_serial,
            'networkId': network_id,
            'state': state
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_assign_organization_licenses_seats(self,
                                                  organization_id,
                                                  assign_organization_licenses_seats):
        """Does a POST request to /organizations/{organizationId}/licenses/assignSeats.

        Assign SM seats to a network. This will increase the managed SM device
        limit of the network

        Args:
            organization_id (string): TODO: type description here. Example: 
            assign_organization_licenses_seats
                (AssignOrganizationLicensesSeats): TODO: type description
                here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/licenses/assignSeats'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(assign_organization_licenses_seats))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_move_organization_licenses(self,
                                          organization_id,
                                          move_organization_licenses):
        """Does a POST request to /organizations/{organizationId}/licenses/move.

        Move licenses to another organization. This will also move any devices
        that the licenses are assigned to

        Args:
            organization_id (string): TODO: type description here. Example: 
            move_organization_licenses (MoveOrganizationLicenses): TODO: type
                description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/licenses/move'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(move_organization_licenses))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_move_organization_licenses_seats(self,
                                                organization_id,
                                                move_organization_licenses_seats):
        """Does a POST request to /organizations/{organizationId}/licenses/moveSeats.

        Move SM seats to another organization

        Args:
            organization_id (string): TODO: type description here. Example: 
            move_organization_licenses_seats (MoveOrganizationLicensesSeats):
                TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/licenses/moveSeats'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(move_organization_licenses_seats))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_renew_organization_licenses_seats(self,
                                                 organization_id,
                                                 renew_organization_licenses_seats):
        """Does a POST request to /organizations/{organizationId}/licenses/renewSeats.

        Renew SM seats of a license. This will extend the license expiration
        date of managed SM devices covered by this license

        Args:
            organization_id (string): TODO: type description here. Example: 
            renew_organization_licenses_seats
                (RenewOrganizationLicensesSeats): TODO: type description here.
                Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/licenses/renewSeats'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(renew_organization_licenses_seats))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_organization_license(self,
                                 organization_id,
                                 license_id):
        """Does a GET request to /organizations/{organizationId}/licenses/{licenseId}.

        Display a license

        Args:
            organization_id (string): TODO: type description here. Example: 
            license_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/licenses/{licenseId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id,
            'licenseId': license_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_organization_license(self,
                                    organization_id,
                                    license_id,
                                    update_organization_license=None):
        """Does a PUT request to /organizations/{organizationId}/licenses/{licenseId}.

        Update a license

        Args:
            organization_id (string): TODO: type description here. Example: 
            license_id (string): TODO: type description here. Example: 
            update_organization_license (UpdateOrganizationLicense, optional):
                TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/licenses/{licenseId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id,
            'licenseId': license_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_organization_license))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body



# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from test_meraki.api_helper import APIHelper
from test_meraki.configuration import Configuration
from test_meraki.controllers.base_controller import BaseController
from test_meraki.http.auth.custom_header_auth import CustomHeaderAuth

class SplashLoginAttemptsController(BaseController):

    """A Controller to access Endpoints in the test_meraki API."""


    def get_network_splash_login_attempts(self,
                                          network_id,
                                          ssid_number=None,
                                          login_identifier=None,
                                          timespan=None):
        """Does a GET request to /networks/{networkId}/splashLoginAttempts.

        List the splash login attempts for a network

        Args:
            network_id (string): TODO: type description here. Example: 
            ssid_number (SsidNumberEnum, optional): Only return the login
                attempts for the specified SSID
            login_identifier (string, optional): The username, email, or phone
                number used during login
            timespan (int, optional): The timespan, in seconds, for the login
                attempts. The period will be from [timespan] seconds ago until
                now. The maximum timespan is 3 months

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/splashLoginAttempts'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'ssidNumber': ssid_number,
            'loginIdentifier': login_identifier,
            'timespan': timespan
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body



# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.override

class UpdateNetworkSwitchSettingsMtu(object):

    """Implementation of the 'updateNetworkSwitchSettingsMtu' model.

    TODO: type model description here.

    Attributes:
        default_mtu_size (int): MTU size for the entire network. Default value
            is 9578.
        overrides (list of Override): Override MTU size for individual
            switches or switch profiles. An empty array will clear overrides.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "default_mtu_size":'defaultMtuSize',
        "overrides":'overrides'
    }

    def __init__(self,
                 default_mtu_size=None,
                 overrides=None):
        """Constructor for the UpdateNetworkSwitchSettingsMtu class"""

        # Initialize members of the class
        self.default_mtu_size = default_mtu_size
        self.overrides = overrides


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        default_mtu_size = dictionary.get('defaultMtuSize')
        overrides = None
        if dictionary.get('overrides') != None:
            overrides = list()
            for structure in dictionary.get('overrides'):
                overrides.append(test_meraki.models.override.Override.from_dictionary(structure))

        # Return an object of this model
        return cls(default_mtu_size,
                   overrides)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.rule_10

class UpdateNetworkSwitchAccessControlLists(object):

    """Implementation of the 'updateNetworkSwitchAccessControlLists' model.

    TODO: type model description here.

    Attributes:
        rules (list of Rule10): An ordered array of the access control list
            rules (not including the default rule). An empty array will clear
            the rules.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "rules":'rules'
    }

    def __init__(self,
                 rules=None):
        """Constructor for the UpdateNetworkSwitchAccessControlLists class"""

        # Initialize members of the class
        self.rules = rules


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        rules = None
        if dictionary.get('rules') != None:
            rules = list()
            for structure in dictionary.get('rules'):
                rules.append(test_meraki.models.rule_10.Rule10.from_dictionary(structure))

        # Return an object of this model
        return cls(rules)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Rule4(object):

    """Implementation of the 'Rule4' model.

    TODO: type model description here.

    Attributes:
        policy (Policy4Enum): 'Deny' traffic specified by this rule
        mtype (Type4Enum): Type of the L7 rule. One of: 'application',
            'applicationCategory', 'host', 'port', 'ipRange'
        value (string): The 'value' of what you want to block. Format of
            'value' varies depending on type of the rule. See sample request.
            The application categories and application ids can be retrieved
            from the the 'MX L7 application categories' endpoint. The
            countries follow the two-letter ISO 3166-1 alpha-2 format.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "policy":'policy',
        "mtype":'type',
        "value":'value'
    }

    def __init__(self,
                 policy=None,
                 mtype=None,
                 value=None):
        """Constructor for the Rule4 class"""

        # Initialize members of the class
        self.policy = policy
        self.mtype = mtype
        self.value = value


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        policy = dictionary.get('policy')
        mtype = dictionary.get('type')
        value = dictionary.get('value')

        # Return an object of this model
        return cls(policy,
                   mtype,
                   value)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.device_fields

class UpdateNetworkSmDeviceFields(object):

    """Implementation of the 'updateNetworkSmDeviceFields' model.

    TODO: type model description here.

    Attributes:
        wifi_mac (string): The wifiMac of the device to be modified.
        id (string): The id of the device to be modified.
        serial (string): The serial of the device to be modified.
        device_fields (DeviceFields): The new fields of the device. Each field
            of this object is optional.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "device_fields":'deviceFields',
        "wifi_mac":'wifiMac',
        "id":'id',
        "serial":'serial'
    }

    def __init__(self,
                 device_fields=None,
                 wifi_mac=None,
                 id=None,
                 serial=None):
        """Constructor for the UpdateNetworkSmDeviceFields class"""

        # Initialize members of the class
        self.wifi_mac = wifi_mac
        self.id = id
        self.serial = serial
        self.device_fields = device_fields


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        device_fields = test_meraki.models.device_fields.DeviceFields.from_dictionary(dictionary.get('deviceFields')) if dictionary.get('deviceFields') else None
        wifi_mac = dictionary.get('wifiMac')
        id = dictionary.get('id')
        serial = dictionary.get('serial')

        # Return an object of this model
        return cls(device_fields,
                   wifi_mac,
                   id,
                   serial)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.whitelisted_rule

class UpdateOrganizationSecurityIntrusionSettings(object):

    """Implementation of the 'updateOrganizationSecurityIntrusionSettings' model.

    TODO: type model description here.

    Attributes:
        whitelisted_rules (list of WhitelistedRule): Sets a list of specific
            SNORT® signatures to whitelist

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "whitelisted_rules":'whitelistedRules'
    }

    def __init__(self,
                 whitelisted_rules=None):
        """Constructor for the UpdateOrganizationSecurityIntrusionSettings class"""

        # Initialize members of the class
        self.whitelisted_rules = whitelisted_rules


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        whitelisted_rules = None
        if dictionary.get('whitelistedRules') != None:
            whitelisted_rules = list()
            for structure in dictionary.get('whitelistedRules'):
                whitelisted_rules.append(test_meraki.models.whitelisted_rule.WhitelistedRule.from_dictionary(structure))

        # Return an object of this model
        return cls(whitelisted_rules)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Rule10(object):

    """Implementation of the 'Rule10' model.

    TODO: type model description here.

    Attributes:
        comment (string): Description of the rule (optional).
        policy (Policy6Enum): 'allow' or 'deny' traffic specified by this
            rule.
        ip_version (IpVersionEnum): IP address version (must be 'any', 'ipv4'
            or 'ipv6'). Applicable only if network supports IPv6. Default
            value is 'ipv4'.
        protocol (Protocol3Enum): The type of protocol (must be 'tcp', 'udp',
            or 'any').
        src_cidr (string): Source IP address (in IP or CIDR notation) or
            'any'.
        src_port (string): Source port. Must be in the range  of 1-65535 or
            'any'. Default is 'any'.
        dst_cidr (string): Destination IP address (in IP or CIDR notation) or
            'any'.
        dst_port (string): Destination port. Must be in the range of 1-65535
            or 'any'. Default is 'any'.
        vlan (string): Incoming traffic VLAN. Must be in the range of 1-4095
            or 'any'. Default is 'any'.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "policy":'policy',
        "protocol":'protocol',
        "src_cidr":'srcCidr',
        "dst_cidr":'dstCidr',
        "comment":'comment',
        "ip_version":'ipVersion',
        "src_port":'srcPort',
        "dst_port":'dstPort',
        "vlan":'vlan'
    }

    def __init__(self,
                 policy=None,
                 protocol=None,
                 src_cidr=None,
                 dst_cidr=None,
                 comment=None,
                 ip_version=None,
                 src_port=None,
                 dst_port=None,
                 vlan=None):
        """Constructor for the Rule10 class"""

        # Initialize members of the class
        self.comment = comment
        self.policy = policy
        self.ip_version = ip_version
        self.protocol = protocol
        self.src_cidr = src_cidr
        self.src_port = src_port
        self.dst_cidr = dst_cidr
        self.dst_port = dst_port
        self.vlan = vlan


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        policy = dictionary.get('policy')
        protocol = dictionary.get('protocol')
        src_cidr = dictionary.get('srcCidr')
        dst_cidr = dictionary.get('dstCidr')
        comment = dictionary.get('comment')
        ip_version = dictionary.get('ipVersion')
        src_port = dictionary.get('srcPort')
        dst_port = dictionary.get('dstPort')
        vlan = dictionary.get('vlan')

        # Return an object of this model
        return cls(policy,
                   protocol,
                   src_cidr,
                   dst_cidr,
                   comment,
                   ip_version,
                   src_port,
                   dst_port,
                   vlan)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.license

class ClaimOrganization(object):

    """Implementation of the 'claimOrganization' model.

    TODO: type model description here.

    Attributes:
        orders (list of string): The numbers of the orders that should be
            claimed
        serials (list of string): The serials of the devices that should be
            claimed
        licenses (list of License): The licenses that should be claimed

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "orders":'orders',
        "serials":'serials',
        "licenses":'licenses'
    }

    def __init__(self,
                 orders=None,
                 serials=None,
                 licenses=None):
        """Constructor for the ClaimOrganization class"""

        # Initialize members of the class
        self.orders = orders
        self.serials = serials
        self.licenses = licenses


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        orders = dictionary.get('orders')
        serials = dictionary.get('serials')
        licenses = None
        if dictionary.get('licenses') != None:
            licenses = list()
            for structure in dictionary.get('licenses'):
                licenses.append(test_meraki.models.license.License.from_dictionary(structure))

        # Return an object of this model
        return cls(orders,
                   serials,
                   licenses)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class EncryptionModeEnum(object):

    """Implementation of the 'EncryptionMode' enum.

    The psk encryption mode for the SSID ('wep' or 'wpa'). This param is only
    valid if the authMode is 'psk'

    Attributes:
        WEP: TODO: type description here.
        WPA: TODO: type description here.

    """

    WEP = 'wep'

    WPA = 'wpa'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class BandSelectionTypeEnum(object):

    """Implementation of the 'BandSelectionType' enum.

    Band selection can be set to either 'ssid' or 'ap'. This param is required
    on creation.

    Attributes:
        SSID: TODO: type description here.
        AP: TODO: type description here.

    """

    SSID = 'ssid'

    AP = 'ap'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class BandOperationModeEnum(object):

    """Implementation of the 'BandOperationMode' enum.

    Choice between 'dual', '2.4ghz' or '5ghz'. Defaults to dual.

    Attributes:
        DUAL: TODO: type description here.
        ENUM_24GHZ: TODO: type description here.
        ENUM_5GHZ: TODO: type description here.

    """

    DUAL = 'dual'

    ENUM_24GHZ = '2.4ghz'

    ENUM_5GHZ = '5ghz'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CreateNetworkSwitchStack(object):

    """Implementation of the 'createNetworkSwitchStack' model.

    TODO: type model description here.

    Attributes:
        name (string): The name of the new stack
        serials (list of string): An array of switch serials to be added into
            the new stack

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "serials":'serials'
    }

    def __init__(self,
                 name=None,
                 serials=None):
        """Constructor for the CreateNetworkSwitchStack class"""

        # Initialize members of the class
        self.name = name
        self.serials = serials


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        serials = dictionary.get('serials')

        # Return an object of this model
        return cls(name,
                   serials)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from test_meraki.api_helper import APIHelper
from test_meraki.configuration import Configuration
from test_meraki.controllers.base_controller import BaseController
from test_meraki.http.auth.custom_header_auth import CustomHeaderAuth

class BluetoothClientsController(BaseController):

    """A Controller to access Endpoints in the test_meraki API."""


    def get_network_bluetooth_clients(self,
                                      network_id,
                                      t_0=None,
                                      timespan=None,
                                      per_page=None,
                                      starting_after=None,
                                      ending_before=None,
                                      include_connectivity_history=None):
        """Does a GET request to /networks/{networkId}/bluetoothClients.

        List the Bluetooth clients seen by APs in this network

        Args:
            network_id (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 7 days from today.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameter t0. The value must be in seconds and be less than or
                equal to 7 days. The default is 1 day.
            per_page (int, optional): The number of entries per page returned.
                Acceptable range is 5 - 1000. Default is 10.
            starting_after (string, optional): A token used by the server to
                indicate the start of the page. Often this is a timestamp or
                an ID but it is not limited to those. This parameter should
                not be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.
            ending_before (string, optional): A token used by the server to
                indicate the end of the page. Often this is a timestamp or an
                ID but it is not limited to those. This parameter should not
                be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.
            include_connectivity_history (bool, optional): Include the
                connectivity history for this client

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/bluetoothClients'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            'timespan': timespan,
            'perPage': per_page,
            'startingAfter': starting_after,
            'endingBefore': ending_before,
            'includeConnectivityHistory': include_connectivity_history
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_bluetooth_client(self,
                                     network_id,
                                     bluetooth_client_id,
                                     include_connectivity_history=None,
                                     connectivity_history_timespan=None):
        """Does a GET request to /networks/{networkId}/bluetoothClients/{bluetoothClientId}.

        Return a Bluetooth client. Bluetooth clients can be identified by
        their ID or their MAC.

        Args:
            network_id (string): TODO: type description here. Example: 
            bluetooth_client_id (string): TODO: type description here.
                Example: 
            include_connectivity_history (bool, optional): Include the
                connectivity history for this client
            connectivity_history_timespan (int, optional): The timespan, in
                seconds, for the connectivityHistory data. By default 1 day,
                86400, will be used.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/bluetoothClients/{bluetoothClientId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'bluetoothClientId': bluetooth_client_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'includeConnectivityHistory': include_connectivity_history,
            'connectivityHistoryTimespan': connectivity_history_timespan
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body



# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.wan_1
import test_meraki.models.wan_2

class UpdateNetworkDeviceManagementInterfaceSettings(object):

    """Implementation of the 'updateNetworkDeviceManagementInterfaceSettings' model.

    TODO: type model description here.

    Attributes:
        wan_1 (Wan1): WAN 1 settings
        wan_2 (Wan2): WAN 2 settings (only for MX devices)

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "wan_1":'wan1',
        "wan_2":'wan2'
    }

    def __init__(self,
                 wan_1=None,
                 wan_2=None):
        """Constructor for the UpdateNetworkDeviceManagementInterfaceSettings class"""

        # Initialize members of the class
        self.wan_1 = wan_1
        self.wan_2 = wan_2


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        wan_1 = test_meraki.models.wan_1.Wan1.from_dictionary(dictionary.get('wan1')) if dictionary.get('wan1') else None
        wan_2 = test_meraki.models.wan_2.Wan2.from_dictionary(dictionary.get('wan2')) if dictionary.get('wan2') else None

        # Return an object of this model
        return cls(wan_1,
                   wan_2)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from test_meraki.api_helper import APIHelper
from test_meraki.configuration import Configuration
from test_meraki.controllers.base_controller import BaseController
from test_meraki.http.auth.custom_header_auth import CustomHeaderAuth

class DevicesController(BaseController):

    """A Controller to access Endpoints in the test_meraki API."""


    def get_network_devices(self,
                            network_id):
        """Does a GET request to /networks/{networkId}/devices.

        List the devices in a network

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/devices'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_claim_network_devices(self,
                                     network_id,
                                     claim_network_devices):
        """Does a POST request to /networks/{networkId}/devices/claim.

        Claim a device into a network

        Args:
            network_id (string): TODO: type description here. Example: 
            claim_network_devices (ClaimNetworkDevices): TODO: type
                description here. Example: 

        Returns:
            void: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/devices/claim'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(claim_network_devices))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

    def get_network_device(self,
                           network_id,
                           serial):
        """Does a GET request to /networks/{networkId}/devices/{serial}.

        Return a single device

        Args:
            network_id (string): TODO: type description here. Example: 
            serial (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/devices/{serial}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'serial': serial
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_device(self,
                              network_id,
                              serial,
                              update_network_device=None):
        """Does a PUT request to /networks/{networkId}/devices/{serial}.

        Update the attributes of a device

        Args:
            network_id (string): TODO: type description here. Example: 
            serial (string): TODO: type description here. Example: 
            update_network_device (UpdateNetworkDevice, optional): TODO: type
                description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/devices/{serial}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'serial': serial
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_device))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_blink_network_device_leds(self,
                                         network_id,
                                         serial,
                                         blink_network_device_leds=None):
        """Does a POST request to /networks/{networkId}/devices/{serial}/blinkLeds.

        Blink the LEDs on a device

        Args:
            network_id (string): TODO: type description here. Example: 
            serial (string): TODO: type description here. Example: 
            blink_network_device_leds (BlinkNetworkDeviceLeds, optional):
                TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/devices/{serial}/blinkLeds'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'serial': serial
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(blink_network_device_leds))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_device_lldp_cdp(self,
                                    network_id,
                                    serial,
                                    timespan=None):
        """Does a GET request to /networks/{networkId}/devices/{serial}/lldp_cdp.

        List LLDP and CDP information for a device

        Args:
            network_id (string): TODO: type description here. Example: 
            serial (string): TODO: type description here. Example: 
            timespan (int, optional): The timespan for which LLDP and CDP
                information will be fetched. Must be in seconds and less than
                or equal to a month (2592000 seconds). LLDP and CDP
                information is sent to the Meraki dashboard every 10 minutes.
                In instances where this LLDP and CDP information matches an
                existing entry in the Meraki dashboard, the data is updated
                once every two hours. Meraki recommends querying LLDP and CDP
                information at an interval slightly greater than two hours, to
                ensure that unchanged CDP / LLDP information can be queried
                consistently.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/devices/{serial}/lldp_cdp'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'serial': serial
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'timespan': timespan
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_device_loss_and_latency_history(self,
                                                    network_id,
                                                    serial,
                                                    ip,
                                                    t_0=None,
                                                    t_1=None,
                                                    timespan=None,
                                                    resolution=None,
                                                    uplink=None):
        """Does a GET request to /networks/{networkId}/devices/{serial}/lossAndLatencyHistory.

        Get the uplink loss percentage and latency in milliseconds for a wired
        network device.

        Args:
            network_id (string): TODO: type description here. Example: 
            serial (string): TODO: type description here. Example: 
            ip (string): The destination IP used to obtain the requested
                stats. This is required.
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 365 days from today.
            t_1 (string, optional): The end of the timespan for the data. t1
                can be a maximum of 31 days after t0.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameters t0 and t1. The value must be in seconds and be less
                than or equal to 31 days. The default is 1 day.
            resolution (int, optional): The time resolution in seconds for
                returned data. The valid resolutions are: 60, 600, 3600,
                86400. The default is 60.
            uplink (UplinkEnum, optional): The WAN uplink used to obtain the
                requested stats. Valid uplinks are wan1, wan2, cellular. The
                default is wan1.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/devices/{serial}/lossAndLatencyHistory'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'serial': serial
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'ip': ip,
            't0': t_0,
            't1': t_1,
            'timespan': timespan,
            'resolution': resolution,
            'uplink': uplink
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_device_performance(self,
                                       network_id,
                                       serial):
        """Does a GET request to /networks/{networkId}/devices/{serial}/performance.

        Return the performance score for a single device. Only primary MX
        devices supported. If no data is available, a 204 error code is
        returned.

        Args:
            network_id (string): TODO: type description here. Example: 
            serial (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/devices/{serial}/performance'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'serial': serial
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_reboot_network_device(self,
                                     network_id,
                                     serial):
        """Does a POST request to /networks/{networkId}/devices/{serial}/reboot.

        Reboot a device

        Args:
            network_id (string): TODO: type description here. Example: 
            serial (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/devices/{serial}/reboot'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'serial': serial
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.post(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_remove_network_device(self,
                                     network_id,
                                     serial):
        """Does a POST request to /networks/{networkId}/devices/{serial}/remove.

        Remove a single device

        Args:
            network_id (string): TODO: type description here. Example: 
            serial (string): TODO: type description here. Example: 

        Returns:
            void: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/devices/{serial}/remove'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'serial': serial
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.post(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

    def get_network_device_uplink(self,
                                  network_id,
                                  serial):
        """Does a GET request to /networks/{networkId}/devices/{serial}/uplink.

        Return the uplink information for a device.

        Args:
            network_id (string): TODO: type description here. Example: 
            serial (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/devices/{serial}/uplink'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'serial': serial
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_organization_devices(self,
                                 organization_id,
                                 per_page=None,
                                 starting_after=None,
                                 ending_before=None):
        """Does a GET request to /organizations/{organizationId}/devices.

        List the devices in an organization

        Args:
            organization_id (string): TODO: type description here. Example: 
            per_page (int, optional): The number of entries per page returned.
                Acceptable range is 3 - 1000. Default is 1000.
            starting_after (string, optional): A token used by the server to
                indicate the start of the page. Often this is a timestamp or
                an ID but it is not limited to those. This parameter should
                not be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.
            ending_before (string, optional): A token used by the server to
                indicate the end of the page. Often this is a timestamp or an
                ID but it is not limited to those. This parameter should not
                be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/devices'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'perPage': per_page,
            'startingAfter': starting_after,
            'endingBefore': ending_before
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body



# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Center(object):

    """Implementation of the 'Center' model.

    The longitude and latitude of the center of your floor plan. The 'center'
    or two adjacent corners (e.g. 'topLeftCorner' and 'bottomLeftCorner') must
    be specified. If 'center' is specified, the floor plan is placed over that
    point with no rotation. If two adjacent corners are specified, the floor
    plan is rotated to line up with the two specified points. The aspect ratio
    of the floor plan's image is preserved regardless of which corners/center
    are specified. (This means if that more than two corners are specified,
    only two corners may be used to preserve the floor plan's aspect ratio.).
    No two points can have the same latitude, longitude pair.

    Attributes:
        lat (float): Latitude
        lng (float): Longitude

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "lat":'lat',
        "lng":'lng'
    }

    def __init__(self,
                 lat=None,
                 lng=None):
        """Constructor for the Center class"""

        # Initialize members of the class
        self.lat = lat
        self.lng = lng


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        lat = dictionary.get('lat')
        lng = dictionary.get('lng')

        # Return an object of this model
        return cls(lat,
                   lng)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Wan2(object):

    """Implementation of the 'Wan2' model.

    WAN 2 settings (only for MX devices)

    Attributes:
        wan_enabled (WanEnabledEnum): Enable or disable the interface (only
            for MX devices). Valid values are 'enabled', 'disabled', and 'not
            configured'.
        using_static_ip (bool): Configue the interface to have static IP
            settings or use DHCP.
        static_ip (string): The IP the device should use on the WAN.
        static_gateway_ip (string): The IP of the gateway on the WAN.
        static_subnet_mask (string): The subnet mask for the WAN.
        static_dns (list of string): Up to two DNS IPs.
        vlan (int): The VLAN that management traffic should be tagged with.
            Applies whether usingStaticIp is true or false.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "wan_enabled":'wanEnabled',
        "using_static_ip":'usingStaticIp',
        "static_ip":'staticIp',
        "static_gateway_ip":'staticGatewayIp',
        "static_subnet_mask":'staticSubnetMask',
        "static_dns":'staticDns',
        "vlan":'vlan'
    }

    def __init__(self,
                 wan_enabled=None,
                 using_static_ip=None,
                 static_ip=None,
                 static_gateway_ip=None,
                 static_subnet_mask=None,
                 static_dns=None,
                 vlan=None):
        """Constructor for the Wan2 class"""

        # Initialize members of the class
        self.wan_enabled = wan_enabled
        self.using_static_ip = using_static_ip
        self.static_ip = static_ip
        self.static_gateway_ip = static_gateway_ip
        self.static_subnet_mask = static_subnet_mask
        self.static_dns = static_dns
        self.vlan = vlan


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        wan_enabled = dictionary.get('wanEnabled')
        using_static_ip = dictionary.get('usingStaticIp')
        static_ip = dictionary.get('staticIp')
        static_gateway_ip = dictionary.get('staticGatewayIp')
        static_subnet_mask = dictionary.get('staticSubnetMask')
        static_dns = dictionary.get('staticDns')
        vlan = dictionary.get('vlan')

        # Return an object of this model
        return cls(wan_enabled,
                   using_static_ip,
                   static_ip,
                   static_gateway_ip,
                   static_subnet_mask,
                   static_dns,
                   vlan)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class SplashAuthSettingsEnum(object):

    """Implementation of the 'SplashAuthSettings' enum.

    Whether clients bound to your policy will bypass splash authorization or
    behave according to the network's rules. Can be one of 'network default'
    or 'bypass'. Only available if your network has a wireless configuration.

    Attributes:
        ENUM_NETWORK DEFAULT: TODO: type description here.
        BYPASS: TODO: type description here.

    """

    ENUM_NETWORK_DEFAULT = 'network default'

    BYPASS = 'bypass'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.reserved_ip_range
import test_meraki.models.dhcp_option

class UpdateNetworkVlan(object):

    """Implementation of the 'updateNetworkVlan' model.

    TODO: type model description here.

    Attributes:
        name (string): The name of the VLAN
        subnet (string): The subnet of the VLAN
        appliance_ip (string): The local IP of the appliance on the VLAN
        vpn_nat_subnet (string): The translated VPN subnet if VPN and VPN
            subnet translation are enabled on the VLAN
        dhcp_handling (DhcpHandlingEnum): The appliance's handling of DHCP
            requests on this VLAN. One of: 'Run a DHCP server', 'Relay DHCP to
            another server' or 'Do not respond to DHCP requests'
        dhcp_relay_server_ips (list of string): The IPs of the DHCP servers
            that DHCP requests should be relayed to
        dhcp_lease_time (DhcpLeaseTimeEnum): The term of DHCP leases if the
            appliance is running a DHCP server on this VLAN. One of: '30
            minutes', '1 hour', '4 hours', '12 hours', '1 day' or '1 week'
        dhcp_boot_options_enabled (bool): Use DHCP boot options specified in
            other properties
        dhcp_boot_next_server (string): DHCP boot option to direct boot
            clients to the server to load the boot file from
        dhcp_boot_filename (string): DHCP boot option for boot filename
        fixed_ip_assignments (object): The DHCP fixed IP assignments on the
            VLAN. This should be an object that contains mappings from MAC
            addresses to objects that themselves each contain "ip" and "name"
            string fields. See the sample request/response for more details.
        reserved_ip_ranges (list of ReservedIpRange): The DHCP reserved IP
            ranges on the VLAN
        dns_nameservers (string): The DNS nameservers used for DHCP responses,
            either "upstream_dns", "google_dns", "opendns", or a newline
            seperated string of IP addresses or domain names
        dhcp_options (list of DhcpOption): The list of DHCP options that will
            be included in DHCP responses. Each object in the list should have
            "code", "type", and "value" properties.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "subnet":'subnet',
        "appliance_ip":'applianceIp',
        "vpn_nat_subnet":'vpnNatSubnet',
        "dhcp_handling":'dhcpHandling',
        "dhcp_relay_server_ips":'dhcpRelayServerIps',
        "dhcp_lease_time":'dhcpLeaseTime',
        "dhcp_boot_options_enabled":'dhcpBootOptionsEnabled',
        "dhcp_boot_next_server":'dhcpBootNextServer',
        "dhcp_boot_filename":'dhcpBootFilename',
        "fixed_ip_assignments":'fixedIpAssignments',
        "reserved_ip_ranges":'reservedIpRanges',
        "dns_nameservers":'dnsNameservers',
        "dhcp_options":'dhcpOptions'
    }

    def __init__(self,
                 name=None,
                 subnet=None,
                 appliance_ip=None,
                 vpn_nat_subnet=None,
                 dhcp_handling=None,
                 dhcp_relay_server_ips=None,
                 dhcp_lease_time=None,
                 dhcp_boot_options_enabled=None,
                 dhcp_boot_next_server=None,
                 dhcp_boot_filename=None,
                 fixed_ip_assignments=None,
                 reserved_ip_ranges=None,
                 dns_nameservers=None,
                 dhcp_options=None):
        """Constructor for the UpdateNetworkVlan class"""

        # Initialize members of the class
        self.name = name
        self.subnet = subnet
        self.appliance_ip = appliance_ip
        self.vpn_nat_subnet = vpn_nat_subnet
        self.dhcp_handling = dhcp_handling
        self.dhcp_relay_server_ips = dhcp_relay_server_ips
        self.dhcp_lease_time = dhcp_lease_time
        self.dhcp_boot_options_enabled = dhcp_boot_options_enabled
        self.dhcp_boot_next_server = dhcp_boot_next_server
        self.dhcp_boot_filename = dhcp_boot_filename
        self.fixed_ip_assignments = fixed_ip_assignments
        self.reserved_ip_ranges = reserved_ip_ranges
        self.dns_nameservers = dns_nameservers
        self.dhcp_options = dhcp_options


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        subnet = dictionary.get('subnet')
        appliance_ip = dictionary.get('applianceIp')
        vpn_nat_subnet = dictionary.get('vpnNatSubnet')
        dhcp_handling = dictionary.get('dhcpHandling')
        dhcp_relay_server_ips = dictionary.get('dhcpRelayServerIps')
        dhcp_lease_time = dictionary.get('dhcpLeaseTime')
        dhcp_boot_options_enabled = dictionary.get('dhcpBootOptionsEnabled')
        dhcp_boot_next_server = dictionary.get('dhcpBootNextServer')
        dhcp_boot_filename = dictionary.get('dhcpBootFilename')
        fixed_ip_assignments = dictionary.get('fixedIpAssignments')
        reserved_ip_ranges = None
        if dictionary.get('reservedIpRanges') != None:
            reserved_ip_ranges = list()
            for structure in dictionary.get('reservedIpRanges'):
                reserved_ip_ranges.append(test_meraki.models.reserved_ip_range.ReservedIpRange.from_dictionary(structure))
        dns_nameservers = dictionary.get('dnsNameservers')
        dhcp_options = None
        if dictionary.get('dhcpOptions') != None:
            dhcp_options = list()
            for structure in dictionary.get('dhcpOptions'):
                dhcp_options.append(test_meraki.models.dhcp_option.DhcpOption.from_dictionary(structure))

        # Return an object of this model
        return cls(name,
                   subnet,
                   appliance_ip,
                   vpn_nat_subnet,
                   dhcp_handling,
                   dhcp_relay_server_ips,
                   dhcp_lease_time,
                   dhcp_boot_options_enabled,
                   dhcp_boot_next_server,
                   dhcp_boot_filename,
                   fixed_ip_assignments,
                   reserved_ip_ranges,
                   dns_nameservers,
                   dhcp_options)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.user

class UpdateNetworkSnmpSettings(object):

    """Implementation of the 'updateNetworkSnmpSettings' model.

    TODO: type model description here.

    Attributes:
        access (Access1Enum): The type of SNMP access. Can be one of 'none'
            (disabled), 'community' (V1/V2c), or 'users' (V3).
        community_string (string): The SNMP community string. Only relevant if
            'access' is set to 'community'.
        users (list of User): The list of SNMP users. Only relevant if
            'access' is set to 'users'.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "access":'access',
        "community_string":'communityString',
        "users":'users'
    }

    def __init__(self,
                 access=None,
                 community_string=None,
                 users=None):
        """Constructor for the UpdateNetworkSnmpSettings class"""

        # Initialize members of the class
        self.access = access
        self.community_string = community_string
        self.users = users


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        access = dictionary.get('access')
        community_string = dictionary.get('communityString')
        users = None
        if dictionary.get('users') != None:
            users = list()
            for structure in dictionary.get('users'):
                users.append(test_meraki.models.user.User.from_dictionary(structure))

        # Return an object of this model
        return cls(access,
                   community_string,
                   users)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class Type5Enum(object):

    """Implementation of the 'Type5' enum.

    One of "delete" or "restrict processing"

    Attributes:
        DELETE: TODO: type description here.
        ENUM_RESTRICT PROCESSING: TODO: type description here.

    """

    DELETE = 'delete'

    ENUM_RESTRICT_PROCESSING = 'restrict processing'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Sunday(object):

    """Implementation of the 'Sunday' model.

    The schedule object for Sunday.

    Attributes:
        active (bool): Whether the schedule is active (true) or inactive
            (false) during the time specified between 'from' and 'to'.
            Defaults to true.
        mfrom (string): The time, from '00:00' to '24:00'. Must be less than
            the time specified in 'to'. Defaults to '00:00'. Only 30 minute
            increments are allowed.
        to (string): The time, from '00:00' to '24:00'. Must be greater than
            the time specified in 'from'. Defaults to '24:00'. Only 30 minute
            increments are allowed.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "active":'active',
        "mfrom":'from',
        "to":'to'
    }

    def __init__(self,
                 active=None,
                 mfrom=None,
                 to=None):
        """Constructor for the Sunday class"""

        # Initialize members of the class
        self.active = active
        self.mfrom = mfrom
        self.to = to


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        active = dictionary.get('active')
        mfrom = dictionary.get('from')
        to = dictionary.get('to')

        # Return an object of this model
        return cls(active,
                   mfrom,
                   to)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class MajorMinorAssignmentModeEnum(object):

    """Implementation of the 'MajorMinorAssignmentMode' enum.

    The way major and minor number should be assigned to nodes in the network.
    ('Unique', 'Non-unique')

    Attributes:
        UNIQUE: TODO: type description here.
        NONUNIQUE: TODO: type description here.

    """

    UNIQUE = 'Unique'

    NONUNIQUE = 'Non-unique'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class MinBitrateTypeEnum(object):

    """Implementation of the 'MinBitrateType' enum.

    Minimum bitrate can be set to either 'band' or 'ssid'. Defaults to band.

    Attributes:
        BAND: TODO: type description here.
        SSID: TODO: type description here.

    """

    BAND = 'band'

    SSID = 'ssid'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Wan21(object):

    """Implementation of the 'Wan21' model.

    The bandwidth settings for the 'wan2' uplink

    Attributes:
        limit_up (int): The maximum upload limit (integer, in Kbps). null
            indicates no limit
        limit_down (int): The maximum download limit (integer, in Kbps). null
            indicates no limit

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "limit_up":'limitUp',
        "limit_down":'limitDown'
    }

    def __init__(self,
                 limit_up=None,
                 limit_down=None):
        """Constructor for the Wan21 class"""

        # Initialize members of the class
        self.limit_up = limit_up
        self.limit_down = limit_down


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        limit_up = dictionary.get('limitUp')
        limit_down = dictionary.get('limitDown')

        # Return an object of this model
        return cls(limit_up,
                   limit_down)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class UniversalSearchKnowledgeBaseSearchEnum(object):

    """Implementation of the 'UniversalSearchKnowledgeBaseSearch' enum.

    The universal search box always visible on Dashboard will, by default,
    present results from the Meraki KB. This configures
        whether these Meraki KB results should be returned. Can be one of
        'default or inherit', 'hide' or 'show'.

    Attributes:
        ENUM_DEFAULT OR INHERIT: TODO: type description here.
        HIDE: TODO: type description here.
        SHOW: TODO: type description here.

    """

    ENUM_DEFAULT_OR_INHERIT = 'default or inherit'

    HIDE = 'hide'

    SHOW = 'show'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Rule(object):

    """Implementation of the 'Rule' model.

    TODO: type model description here.

    Attributes:
        comment (string): Description of the rule (optional)
        policy (PolicyEnum): 'allow' or 'deny' traffic specified by this rule
        protocol (ProtocolEnum): The type of protocol (must be 'tcp', 'udp',
            'icmp' or 'any')
        src_port (string): Comma-separated list of source port(s) (integer in
            the range 1-65535), or 'any'
        src_cidr (string): Comma-separated list of source IP address(es) (in
            IP or CIDR notation), or 'any' (note: FQDN not supported for
            source addresses)
        dest_port (string): Comma-separated list of destination port(s)
            (integer in the range 1-65535), or 'any'
        dest_cidr (string): Comma-separated list of destination IP address(es)
            (in IP or CIDR notation), fully-qualified domain names (FQDN) or
            'any'
        syslog_enabled (bool): Log this rule to syslog (true or false, boolean
            value) - only applicable if a syslog has been configured
            (optional)

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "policy":'policy',
        "protocol":'protocol',
        "src_cidr":'srcCidr',
        "dest_cidr":'destCidr',
        "comment":'comment',
        "src_port":'srcPort',
        "dest_port":'destPort',
        "syslog_enabled":'syslogEnabled'
    }

    def __init__(self,
                 policy=None,
                 protocol=None,
                 src_cidr=None,
                 dest_cidr=None,
                 comment=None,
                 src_port=None,
                 dest_port=None,
                 syslog_enabled=None):
        """Constructor for the Rule class"""

        # Initialize members of the class
        self.comment = comment
        self.policy = policy
        self.protocol = protocol
        self.src_port = src_port
        self.src_cidr = src_cidr
        self.dest_port = dest_port
        self.dest_cidr = dest_cidr
        self.syslog_enabled = syslog_enabled


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        policy = dictionary.get('policy')
        protocol = dictionary.get('protocol')
        src_cidr = dictionary.get('srcCidr')
        dest_cidr = dictionary.get('destCidr')
        comment = dictionary.get('comment')
        src_port = dictionary.get('srcPort')
        dest_port = dictionary.get('destPort')
        syslog_enabled = dictionary.get('syslogEnabled')

        # Return an object of this model
        return cls(policy,
                   protocol,
                   src_cidr,
                   dest_cidr,
                   comment,
                   src_port,
                   dest_port,
                   syslog_enabled)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class Mode2Enum(object):

    """Implementation of the 'Mode2' enum.

    Either 'renew' or 'addDevices'. 'addDevices' will increase the license
    limit, while 'renew' will extend the amount of time until expiration. This
    parameter is legacy and only applies to coterm licensing; it should not be
    specified when claiming per-device licenses. Please see <a target='_blank'
    href='https://documentation.meraki.com/zGeneral_Administration/Licensing/Ad
    ding_an_Enterprise_license_to_an_existing_Dashboard_account'>this
    article</a> for more information.

    Attributes:
        ADDDEVICES: TODO: type description here.
        RENEW: TODO: type description here.

    """

    ADDDEVICES = 'addDevices'

    RENEW = 'renew'

